==> checkstyle-8.42-tests.jar: com/puppycrawl/tools/checkstyle/checks/annotation/annotationusestyle/InputAnnotationUseStyleCompactNoArray.java <==
package com.puppycrawl.tools.checkstyle.checks.annotation.annotationusestyle;

/* Config:
 * closingParens = ignore
 * elementStyle = COMPACT_NO_ARRAY
 * trailingArrayComma = ignore
 */
@Deprecated
@SomeArrays(pooches={DOGS.LEO}) // violation
@SuppressWarnings({""}) // violation
public class InputAnnotationUseStyleCompactNoArray
{

}

@SomeArrays(pooches={DOGS.LEO}, um={}, duh={"bleh"}) // violation
@SuppressWarnings("") //compact_no_array
@Deprecated()
class Dep6 {

}

@Deprecated
@SomeArrays(pooches={DOGS.LEO}) // violation
@SuppressWarnings({""}) // violation
enum SON6 {

    @Deprecated
    @SomeArrays(pooches={DOGS.LEO}, um={""}, duh={"bleh"}) // violation
    @APooch(dog=DOGS.HERBIE)
    @Another("") //compact_no_array
    ETHAN
}

@InputAnnotationUseStyleCustomAnnotation()
enum DOGS6 {

    @Deprecated()
    LEO,
    HERBIE
}

@interface SomeArrays6 {
    @Another("") //compact
    String[] um() default {};
    @Another({""}) //compact // violation
    String[] duh() default {};
    @Another(value={""}) //expanded // violation
    DOGS[] pooches();
}

@Another(value={""}) //expanded // violation
enum E6 {

}

@interface APooch6 {
    DOGS dog();
}

@interface Another6 {
    String[] value() default {};
    @Another({"foo", "bar"}) //compact style
    String value1() default "";
}

@SomeArrays(pooches = {})
@Another({})
class Closing6 {
    static final String UN_U = "UN_U";

    @SuppressWarnings(value = UN_U)
    int d;
}

@AnnotationWithAnnotationValue(@Another)
class Example21 {}
@AnnotationWithAnnotationValue(value = @Another)
class Example22 {}
@AnnotationWithAnnotationValue(@Another())
class Example23 {}
@AnnotationWithAnnotationValue(value = @Another())
class Example24 {}

class Foo6 {
   Foo6(@Another String par1, @Another int par2) {}
}

@interface AnnotationWithAnnotationValue6 {
    Another value();
}

==> checkstyle-8.45.1-tests.jar: com/puppycrawl/tools/checkstyle/checks/annotation/annotationusestyle/InputAnnotationUseStyleCompactNoArray.java <==
/*
AnnotationUseStyle
elementStyle = (default)compact_no_array
closingParens = ignore
trailingArrayComma = ignore


*/

package com.puppycrawl.tools.checkstyle.checks.annotation.annotationusestyle;

@Deprecated
@SomeArrays(pooches={DOGS.LEO}) // violation
@SuppressWarnings({""}) // violation
public class InputAnnotationUseStyleCompactNoArray
{

}

@SomeArrays(pooches={DOGS.LEO}, um={}, duh={"bleh"}) // violation
@SuppressWarnings("") //compact_no_array
@Deprecated()
class Dep6 {

}

@Deprecated
@SomeArrays(pooches={DOGS.LEO}) // violation
@SuppressWarnings({""}) // violation
enum SON6 {

    @Deprecated
    @SomeArrays(pooches={DOGS.LEO}, um={""}, duh={"bleh"}) // violation
    @APooch(dog=DOGS.HERBIE)
    @Another("") //compact_no_array
    ETHAN
}

@InputAnnotationUseStyleCustomAnnotation()
enum DOGS6 {

    @Deprecated()
    LEO,
    HERBIE
}

@interface SomeArrays6 {
    @Another("") //compact
    String[] um() default {};
    @Another({""}) //compact // violation
    String[] duh() default {};
    @Another(value={""}) //expanded // violation
    DOGS[] pooches();
}

@Another(value={""}) //expanded // violation
enum E6 {

}

@interface APooch6 {
    DOGS dog();
}

@interface Another6 {
    String[] value() default {};
    @Another({"foo", "bar"}) //compact style
    String value1() default "";
}

@SomeArrays(pooches = {})
@Another({})
class Closing6 {
    static final String UN_U = "UN_U";

    @SuppressWarnings(value = UN_U)
    int d;
}

@AnnotationWithAnnotationValue(@Another)
class Example21 {}
@AnnotationWithAnnotationValue(value = @Another)
class Example22 {}
@AnnotationWithAnnotationValue(@Another())
class Example23 {}
@AnnotationWithAnnotationValue(value = @Another())
class Example24 {}

class Foo6 {
   Foo6(@Another String par1, @Another int par2) {}
}

@interface AnnotationWithAnnotationValue6 {
    Another value();
}
